package de.intevation.flys.client.server;

import org.w3c.dom.Document;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

import de.intevation.artifacts.common.ArtifactNamespaceContext;
import de.intevation.artifacts.common.utils.ClientProtocolUtils;
import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;
import de.intevation.artifacts.httpclient.http.response.DocumentResponseHandler;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Collection;
import de.intevation.flys.client.shared.model.DefaultCollection;
import de.intevation.flys.client.client.services.CreateCollectionService;


/**
 * This interface provides the createCollection service to create new
 * collections in the artifact server.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class CreateCollectionServiceImpl
extends      RemoteServiceServlet
implements   CreateCollectionService
{
    /** XPath to figure out the uuid of the created collection.*/
    public static final String XPATH_COLLECTION_UUID =
        "/art:result/art:artifact-collection/@art:uuid";

    /** Error message key that is thrown if an error occured while creating
     *  a new collection.*/
    public static final String ERROR_CREATE_COLLECTION =
        "error_create_collection";


    public Collection create(String serverUrl, String locale, String ownerId)
    throws ServerException
    {
        System.out.println("Start creating a new collection.");

        Document create   =
            ClientProtocolUtils.newCreateCollectionDocument(null);
        HttpClient client = new HttpClientImpl(serverUrl, locale);

        try {
            Document doc = (Document) client.createCollection(
                create, ownerId, new DocumentResponseHandler());

            String uuid = XMLUtils.xpathString(
                doc, XPATH_COLLECTION_UUID, ArtifactNamespaceContext.INSTANCE);

            if (uuid == null || uuid.trim().length() == 0) {
                throw new ServerException(ERROR_CREATE_COLLECTION);
            }

            return new DefaultCollection(uuid);
        }
        catch (ConnectionException ce) {
            System.err.println(ce.getLocalizedMessage());
        }

        throw new ServerException(ERROR_CREATE_COLLECTION);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
